"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.17.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.model.scope import Scope
globals()['Scope'] = Scope
from nuaudit_python_autogen.model.permission_mutation import PermissionMutation


class TestPermissionMutation(unittest.TestCase):
    """PermissionMutation unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testPermissionMutation(self):
        """Test PermissionMutation"""
        # FIXME: construct object with mandatory attributes with example values
        # model = PermissionMutation()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
