"""
    Nuaudit

    Nanaged Audit Trails for Cloud Applications.  # noqa: E501

    The version of the OpenAPI document: 0.17.0
    Contact: support@nuaudit.com
    Generated by: https://openapi-generator.tech
"""


import unittest

import nuaudit_python_autogen
from nuaudit_python_autogen.api.settings_api import SettingsApi  # noqa: E501


class TestSettingsApi(unittest.TestCase):
    """SettingsApi unit test stubs"""

    def setUp(self):
        self.api = SettingsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_get_settings_for_organization(self):
        """Test case for get_settings_for_organization

        Get Settings For Organization  # noqa: E501
        """
        pass

    def test_update_settings_for_organization(self):
        """Test case for update_settings_for_organization

        Update Settings For Organization  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
